@@ -119,3 +119,11 @@ class dual_circuit():
     def clipp_graph(self):
         for i in range(2):
             self.layer[i].clipp_graph()
+
+
+    # output
+    def plot_circuit(self):
+
+        fig=dx.plot_networkx_dual(self)
+
+        return fig
